import React from 'react'
import {
  VStack,
  HStack,
  Box,
  Text,
  Badge
} from '@chakra-ui/react'
import { useTranslation } from 'react-i18next'

interface CourseAttendanceProps {
  courses: Array<{id: string, name: string, attendanceRate: number}>
}

export const CourseAttendanceList: React.FC<CourseAttendanceProps> = ({ courses }) => {
  const { t } = useTranslation()
  
  // Определяем цвет для прогресса в зависимости от значения
  const getProgressColor = (value: number) => {
    if (value > 80) return 'green'
    if (value > 50) return 'blue'
    if (value > 30) return 'yellow'
    return 'red'
  }
  
  if (!courses?.length) {
    return (
      <Text color="gray.500" fontSize="sm" textAlign="center">
        {t('journal.pl.overview.noAttendanceData')}
      </Text>
    )
  }
  
  return (
    <Box>
      <Text fontWeight="medium" fontSize="sm" mb={2}>
        {t('journal.pl.overview.topAttendanceCourses')}:
      </Text>
      
      <VStack align="stretch" spacing={2}>
        {courses.map((course, index) => (
          <HStack key={course.id} spacing={2}>
            <Badge colorScheme={['green', 'blue', 'yellow'][index]}>
              #{index + 1}
            </Badge>
            <Text fontSize="sm" fontWeight="medium" isTruncated flex="1">
              {course.name}
            </Text>
            <Badge colorScheme={getProgressColor(course.attendanceRate)}>
              {Math.round(course.attendanceRate)}%
            </Badge>
          </HStack>
        ))}
      </VStack>
    </Box>
  )
} 