import React from 'react'
import {
  Box,
  HStack,
  Text,
  Badge,
  Tooltip,
  VStack
} from '@chakra-ui/react'
import { useTranslation } from 'react-i18next'

interface WeekdayActivityChartProps {
  weekdayActivity: number[]
  mostActiveDayIndex: number
}

export const WeekdayActivityChart: React.FC<WeekdayActivityChartProps> = ({
  weekdayActivity,
  mostActiveDayIndex
}) => {
  const { t } = useTranslation()

  // Переводим день недели в читаемый формат
  const getDayOfWeekName = (dayIndex: number) => {
    const days = [
      'journal.pl.days.sunday',
      'journal.pl.days.monday',
      'journal.pl.days.tuesday',
      'journal.pl.days.wednesday',
      'journal.pl.days.thursday',
      'journal.pl.days.friday',
      'journal.pl.days.saturday'
    ]
    return t(days[dayIndex])
  }
  
  // Получаем короткое название дня недели (первая буква)
  const getShortDayName = (dayIndex: number) => {
    return t(`journal.pl.days.${['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday'][dayIndex]}`).charAt(0)
  }
  
  // Формируем подсказку для дня недели
  const getDayTooltip = (dayIndex: number, count: number) => {
    return `${t(`journal.pl.days.${['sunday', 'monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday'][dayIndex]}`)}:
${count} ${t('journal.pl.overview.lessons').toLowerCase()}`
  }
  
  // Если нет данных по активности, показываем сообщение
  if (!weekdayActivity.some(count => count > 0)) {
    return (
      <Box textAlign="center" color="gray.500" fontSize="sm">
        {t('journal.pl.overview.noAttendanceData')}
      </Box>
    )
  }
  
  return (
    <VStack align="start" width="100%">
      <Text fontSize="sm" fontWeight="medium">
        {t('journal.pl.overview.mostActiveDay')}:
      </Text>
      <Badge colorScheme="blue" fontSize="md" px={2} py={1}>
        {getDayOfWeekName(mostActiveDayIndex)}
      </Badge>
      
      {/* Визуализация активности по дням недели */}
      <Box w="100%" mt={2}>
        <HStack spacing={1} w="100%" justify="space-between">
          {weekdayActivity.map((count, index) => (
            <Tooltip 
              key={index} 
              label={getDayTooltip(index, count)}
            >
              <Box>
                <Box 
                  h={`${Math.max((count / Math.max(...weekdayActivity, 1)) * 50, 3)}px`} 
                  w="12px" 
                  bg={index === mostActiveDayIndex ? 'blue.400' : 'gray.300'}
                  minH="3px"
                  borderRadius="sm"
                />
                <Text fontSize="xs" textAlign="center" mt={1}>
                  {getShortDayName(index)}
                </Text>
              </Box>
            </Tooltip>
          ))}
        </HStack>
      </Box>
    </VStack>
  )
} 